@@ -1,7 +1,7 @@
 from datetime import datetime
 import pickle
 from os import path, remove
-from click import echo
+
 def cacheAge(self):
 	return datetime.utcnow() - self.last_sync
 
@@ -13,7 +13,7 @@ def loadCache(org,appcfg):
 		with open (f, "rb") as pFile:
 			org_cached = pickle.load(pFile)
 		if org_cached.lastsync is None:
-			echo(f'Has Cache! But it is stale, re-syncing')
+			print(f'Has Cache! But it is stale, re-syncing')
 			clearCache(org,appcfg)
 			org.cached = False
 
@@ -26,7 +26,7 @@ def loadCache(org,appcfg):
 			org.cached = False
 
 	else:
-		echo('No Cahce Found')
+		print('No Cahce Found')
 		org.cached = False
 
 		
