@@ -1,7 +1,7 @@
 from autosync import lib
 from meraki.exceptions import AsyncAPIError
 from .ReSync import reSYNC
-from click import echo
+
 
 
 async def clone(network, master, appcfg, db, net_id, netName, product,oFunc):
@@ -13,13 +13,13 @@ async def clone(network, master, appcfg, db, net_id, netName, product,oFunc):
 				await eval(
 					f"network.Update_{task}( master,appcfg,db,net_id,task,netName)")
 			except Exception as e:
-				echo(f'{lib.bc.FAIL} Network: {netName} ')
-				echo(f'\t\t - {lib.bc.WARNING}Override for {product} Task: {task} failed with Error {e}{lib.bc.Default}')
+				print(f'{lib.bc.FAIL} Network: {netName} ')
+				print(f'\t\t - {lib.bc.WARNING}Override for {product} Task: {task} failed with Error {e}{lib.bc.Default}')
 		else:
 			masterSetting = getattr(master, task)
 			networkSetting = getattr(network, task)
 			if not await lib.compare(masterSetting, networkSetting):
-				echo(
+				print(
 					f'\t {lib.bc.OKGREEN}-Updating {task}...{lib.bc.ENDC}')
 				if appcfg.WRITE:
 					configure = getattr(merakiFunction, f"update{task}")
@@ -28,11 +28,11 @@ async def clone(network, master, appcfg, db, net_id, netName, product,oFunc):
 						await  reSYNC(merakiFunction, net_id, network, task,
 									  product,appcfg)
 					except AsyncAPIError as e:
-						echo(
+						print(
 							f'\t {lib.bc.FAIL} Error Running Setting {task} Error Message: {str(e)}  {lib.bc.Default}')
 					appcfg.CLEAN = True
 					network.ReSync = False
 				else:
-					echo(f"Write Disabled")
+					print(f"Write Disabled")
 			else:
-				echo(f'\t{lib.bc.OKBLUE} {netName} {lib.bc.OKGREEN}-Settings for  {task} Matched Master{lib.bc.ENDC}')
+				print(f'\t{lib.bc.OKBLUE} {netName} {lib.bc.OKGREEN}-Settings for  {task} Matched Master{lib.bc.ENDC}')
