@@ -3,7 +3,7 @@ from autosync import lib
 import asyncio
 import logging
 from .processor import validateNetworkProcessor
-from click import echo 
+ 
 class ValidateOrginization(threading.Thread):
 	def __init__(self,org,appcfg,masternet):
 		threading.Thread.__init__(self)
@@ -16,9 +16,9 @@ class ValidateOrginization(threading.Thread):
 		lib.storeCache(self.org, self.appcfg)
 
 	async def _asyncRun(self):
-		echo(f'\tOrgName: {self.org.name}Thread PID:{threading.currentThread().native_id}')
+		print(f'\tOrgName: {self.org.name}Thread PID:{threading.currentThread().native_id}')
 		threading.currentThread().setName(self.org.name)
-		echo(f'\tThread Name:{threading.currentThread().name}')
+		print(f'\tThread Name:{threading.currentThread().name}')
 		with lib.MerakiAsyncApi(self.appcfg) as db:
 			logger = logging.getLogger('meraki.aio')
 			logger.setLevel(logging.WARNING)
